# takeaction: content as actions
# Copyright (C) 2007 Plone Solutions AS
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
from Products.GenericSetup.utils import exportObjects
from Products.GenericSetup.utils import importObjects
from Products.GenericSetup.utils import PropertyManagerHelpers
from Products.GenericSetup.utils import XMLAdapterBase

from Products.CMFCore.utils import getToolByName

from interfaces import ITakeActionTool

class TakeActionToolXMLAdapter(XMLAdapterBase, PropertyManagerHelpers):
    """XML im- and exporter for TakeActionTool"""
    
    __used_for__ = ITakeActionTool

    _LOGGER_ID = 'takeaction'

    name = 'takeaction'

    def _exportNode(self):
        """Export the object as a DOM node"""
        
        node = self._getObjectNode('object')
        node.appendChild(self._extractProperties())

        self._logger.info('TakeAction tool exported.')
        
        return node

    def _importNode(self, node):
        """Import the object from the DOM node"""
        
        if self.environ.shouldPurge():
            self._purgeProperties()

        self._initProperties(node)

        self._logger.info('TakeAction tool imported.')


def importTakeActionTool(context):
    """Import TakeAction tool settings from an XML file.
    """
    site = context.getSite()
    tool = getToolByName(site, 'portal_takeaction')

    importObjects(tool, '', context)

def exportTakeActionTool(context):
    """Export TakeAction tool settings as an XML file.
    """
    site = context.getSite()
    tool = getToolByName(site, 'portal_takeaction', None)
    if tool is None:
        logger = context.getLogger('takeaction')
        logger.info('Nothing to export.')
        return

    exportObjects(tool, '', context)
